import React, { Component } from 'react';

import App from '../App';

import Minimal from '../configurations/evolution/Minimal';
import MinimalRounded from '../configurations/evolution/MinimalRounded';
import MinimalRoundedDetailed from '../configurations/evolution/MinimalRoundedDetailed';

import Burst from '../configurations/components/Burst';
import Iris from '../configurations/components/Iris';
import IndexComponent from '../configurations/components/IndexComponent';
import Hand from '../configurations/components/Hand';

import Steel from '../configurations/backgrounds/Steel';
import GreyFume from '../configurations/backgrounds/GreyFume';

import Chronograph from '../configurations/models/Chronograph';
import ColorfulChronoSquare from '../configurations/models/ColorfulChronoSquare';
import Panda from '../configurations/models/Panda';
import PandaSquare from '../configurations/models/PandaSquare';
import SmallSeconds from '../configurations/models/SmallSeconds';
import SmallSecondsSquare from '../configurations/models/SmallSecondsSquare';
import ColorfulChrono from '../configurations/models/ColorfulChrono';

import '../index.css';

class All extends Component {
    render() {
        return (
            <div>
                <div className="bg-success text-white">
                    <div className="container">
                        <div className="pt-5 pb-4">
                            <h1>React-Bootstrap-Design</h1>
                            <h6 className="text-gray">Wireframing and Illustrating with React.js and Bootstrap 4</h6>
                            <p className="text-gray mb-0">Check out the project on <a className="text-white" href="https://github.com/Harry-Anderson/react-bootstrap-design" target="_blank" rel="noopener noreferrer">GitHub</a>          and on <a className="text-white" href="https://www.npmjs.com/package/react-bootstrap-design" target="_blank" rel="noopener noreferrer">NPM</a></p>
                        </div>
                    </div>
                </div>
                <div className="container pt-4 pb-5">
                    <div className="row mb-4">
                        <div className="col-md-12 col-lg-9">
                            <h2>What is React-Bootstrap-Design?</h2>
                            <p>This is a passion project inspired by a talk that I heard couple of years ago at the FrontEnd Conference in Zurich,
                        where a designer was programatically generating page-layouts to automate his design process. The presentation had
                        me wondering whether it would be possible to apply the same process to product design, so I built this JavaScript
                        library to code 'realistic' product sketches.</p>
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App  key="Minimal" styles={Minimal} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App  key="MinimalRounded" styles={MinimalRounded} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App  key="MinimalRoundedDetailed" styles={MinimalRoundedDetailed} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App  key="Chronograph" styles={Chronograph} />
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-md-12 col-lg-9">
                            <div className="row">
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App  key="IndexComponent" styles={IndexComponent} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App  key="Hand" styles={Hand} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App  key="Burst" styles={Burst} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App  key="Iris" styles={Iris} />
                                </div>
                            </div>
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-md-12 col-lg-9">
                            <div className="row">
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App  key="Steel" styles={Steel} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App  key="GreyFume" styles={GreyFume} />
                                </div>
                            </div>
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{ColorfulChrono.header}</h4>
                            <App  key="ColorfulChrono" styles={ColorfulChrono} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{SmallSecondsSquare.header}</h4>
                            <App  key="SmallSecondsSquare" styles={SmallSecondsSquare} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{PandaSquare.header}</h4>
                            <App  key="PandaSquare" styles={PandaSquare} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{ColorfulChronoSquare.header}</h4>
                            <App  key="ColorfulChronoSquare" styles={ColorfulChronoSquare} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{SmallSeconds.header}</h4>
                            <App  key="SmallSeconds" styles={SmallSeconds} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{Panda.header}</h4>
                            <App  key="Panda" styles={Panda} />
                        </div>
                    </div>
                </div>

                <footer className="footer">
                    <div className="container">
                        <p className="mb-0">Created by <a href="https://harry-anderson.github.io/" target="_blank" rel="noopener noreferrer">Harry Anderson</a></p>
                    </div>
                </footer>
            </div>
        );
    }
}

export default All;