import React, { Component } from 'react';

class Hand extends Component {
    constructor(props) {
        super(props);

        this.state = {
            timezoneOffset : null,
            hour : null,
            minute : null,
            second : null
        }
    }

    componentWillMount() {
        var dt = new Date();
        var timezoneOffset = dt.getTimezoneOffset() / 60;

        var hour;
        if (this.props.type === 'hour') {
            hour = dt.getHours();
        }

        var minute;
        if (this.props.type === 'minute') {
            minute = dt.getMinutes();
        }

        var second;
        if (this.props.type === 'second') {
            second = dt.getSeconds();
        }

        this.setState({
            timezoneOffset : timezoneOffset,
            hour : hour,
            minute : minute,
            second : second
        });
    }

    componentDidMount() {
        setInterval(this.updateTime.bind(this), 1000);
    }

    updateTime() {
        var dt = new Date()
            , hour = dt.getHours()
            , minute = dt.getMinutes()
            , second = dt.getSeconds();

        this.setState(
            {
                hour : hour,
                minute : minute,
                second : second
            }
        );
    }

    render() {
        var handWrapperStyles = {
            transform : '',
            zIndex : '',
            position: 'absolute',
	        top: '50%',
            left: '0',
	        width: '100%',
	        backgroundColor: 'transparent !important'            
        };

        var handStyles = {
            border: '',
            width:'50%',
            margin: '0',
            height: '2px'
        };

        var positionOffset = 90;
        var handPosition = positionOffset;

        if (this.props.type === 'hour') {
            var hour;
            if (typeof this.props.timeZone !== 'undefined') {
                hour = this.state.hour + (this.state.timezoneOffset + this.props.timeZone);
            } else {
                hour = this.state.hour;
            }

            if (hour >= 12) {
                hour = hour - 12;
            }
            if (hour === 0) {
                hour = 12;
            }
            handPosition = (hour * (360/12)) + positionOffset;
            handWrapperStyles.zIndex = 1;
        }

        if (this.props.type === 'minute') {
            var minute = this.state.minute;

            handPosition = (minute * 6) + positionOffset;
            handWrapperStyles.zIndex = 2;
        }

        if (this.props.type === 'second') {
            var second = this.state.second;

            handPosition = (second * 6) + positionOffset;
            handWrapperStyles.zIndex = 3;
        }

        handWrapperStyles.transform = 'rotate(' + handPosition + 'deg)';

        var handColor;
        if (this.props.styles && this.props.styles.color) {
            handColor = this.props.styles.color;
        }

        if (this.props.styles && this.props.styles.border) {
            handStyles.border = this.props.styles.border;
        }

        if (this.props.styles && this.props.styles.length) {
            handStyles.width = this.props.styles.length;
        }

        if (this.props.styles && this.props.styles.margin) {
            handStyles.margin = this.props.styles.margin;
        }

        if (this.props.styles && this.props.styles.width) {
            handStyles.height = this.props.styles.width;
        }

        return (
            <div className="hand" style={handWrapperStyles}>
                <div className={handColor} style={handStyles} />
            </div>
        )
    }
};

export default Hand